# sensorbucket
SensorBucket processes data from different sources and devices into a single standardized format. 
An applications connected to SensorBucket, can use all devices SensorBucket supports.

Missing a device or source? SensorBucket is designed to be scalable and extendable. Create your own worker
that receives data from an AMQP source, process said data and output in the expected worker output format.

Find out more at: https://developer.sensorbucket.nl/

Developed and designed by Provincie Zeeland and Pollex


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonNextgenClientCodegen
For more information, please visit [https://sensorbucket.nl](https://sensorbucket.nl)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import sensorbucket
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import sensorbucket
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import sensorbucket
from sensorbucket.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://sensorbucket.nl/api
# See configuration.py for a list of all supported configuration parameters.
configuration = sensorbucket.Configuration(
    host = "https://sensorbucket.nl/api"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = sensorbucket.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)


# Enter a context with an instance of the API client
with sensorbucket.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = sensorbucket.DevicesApi(api_client)
    create_device_request = sensorbucket.CreateDeviceRequest() # CreateDeviceRequest |  (optional)

    try:
        # Create device
        api_response = api_instance.create_device(create_device_request=create_device_request)
        print("The response of DevicesApi->create_device:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DevicesApi->create_device: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://sensorbucket.nl/api*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DevicesApi* | [**create_device**](docs/DevicesApi.md#create_device) | **POST** /devices | Create device
*DevicesApi* | [**create_device_sensor**](docs/DevicesApi.md#create_device_sensor) | **POST** /devices/{device_id}/sensors | Create sensor for device
*DevicesApi* | [**delete_device_sensor**](docs/DevicesApi.md#delete_device_sensor) | **DELETE** /device/{device_id}/sensors/{sensor_code} | Delete sensor
*DevicesApi* | [**get_device**](docs/DevicesApi.md#get_device) | **GET** /devices/{id} | Get device
*DevicesApi* | [**list_device_sensors**](docs/DevicesApi.md#list_device_sensors) | **GET** /devices/{device_id}/sensors | List sensors device
*DevicesApi* | [**list_devices**](docs/DevicesApi.md#list_devices) | **GET** /devices | List devices
*DevicesApi* | [**list_sensors**](docs/DevicesApi.md#list_sensors) | **GET** /sensors | List sensors
*DevicesApi* | [**update_device**](docs/DevicesApi.md#update_device) | **PATCH** /devices/{id} | Update device properties
*MeasurementsApi* | [**list_datastreams**](docs/MeasurementsApi.md#list_datastreams) | **GET** /datastreams | List all datastreams
*MeasurementsApi* | [**query_measurements**](docs/MeasurementsApi.md#query_measurements) | **GET** /measurements | Query measurements
*PipelinesApi* | [**create_pipeline**](docs/PipelinesApi.md#create_pipeline) | **POST** /pipelines | Create pipeline
*PipelinesApi* | [**disable_pipeline**](docs/PipelinesApi.md#disable_pipeline) | **DELETE** /pipelines/{id} | Disable pipeline
*PipelinesApi* | [**get_pipeline**](docs/PipelinesApi.md#get_pipeline) | **GET** /pipelines/{id} | Get pipeline
*PipelinesApi* | [**list_pipelines**](docs/PipelinesApi.md#list_pipelines) | **GET** /pipelines | List pipelines
*PipelinesApi* | [**update_pipeline**](docs/PipelinesApi.md#update_pipeline) | **PATCH** /pipelines/{id} | Update pipeline
*UplinkApi* | [**process_uplink_data**](docs/UplinkApi.md#process_uplink_data) | **POST** /uplinks/{pipeline_id} | Process uplink message


## Documentation For Models

 - [CreateDevice201Response](docs/CreateDevice201Response.md)
 - [CreateDeviceRequest](docs/CreateDeviceRequest.md)
 - [CreateDeviceSensor201Response](docs/CreateDeviceSensor201Response.md)
 - [CreatePipeline200Response](docs/CreatePipeline200Response.md)
 - [CreatePipelineRequest](docs/CreatePipelineRequest.md)
 - [CreateSensorRequest](docs/CreateSensorRequest.md)
 - [Datastream](docs/Datastream.md)
 - [DeleteDeviceSensor200Response](docs/DeleteDeviceSensor200Response.md)
 - [Device](docs/Device.md)
 - [DisablePipeline200Response](docs/DisablePipeline200Response.md)
 - [GetDevice200Response](docs/GetDevice200Response.md)
 - [GetPipeline200Response](docs/GetPipeline200Response.md)
 - [ListDatastreams200Response](docs/ListDatastreams200Response.md)
 - [ListDatastreams200ResponseAllOf](docs/ListDatastreams200ResponseAllOf.md)
 - [ListDeviceSensors200Response](docs/ListDeviceSensors200Response.md)
 - [ListDeviceSensors200ResponseAllOf](docs/ListDeviceSensors200ResponseAllOf.md)
 - [ListDevices200Response](docs/ListDevices200Response.md)
 - [ListDevices200ResponseAllOf](docs/ListDevices200ResponseAllOf.md)
 - [ListPipelines200Response](docs/ListPipelines200Response.md)
 - [ListPipelines200ResponseAllOf](docs/ListPipelines200ResponseAllOf.md)
 - [Measurement](docs/Measurement.md)
 - [PaginatedResponse](docs/PaginatedResponse.md)
 - [PaginatedResponseLinks](docs/PaginatedResponseLinks.md)
 - [Pipeline](docs/Pipeline.md)
 - [QueryMeasurements200Response](docs/QueryMeasurements200Response.md)
 - [QueryMeasurements200ResponseAllOf](docs/QueryMeasurements200ResponseAllOf.md)
 - [Sensor](docs/Sensor.md)
 - [UpdateDevice200Response](docs/UpdateDevice200Response.md)
 - [UpdateDeviceRequest](docs/UpdateDeviceRequest.md)
 - [UpdatePipeline200Response](docs/UpdatePipeline200Response.md)
 - [UpdatePipelineRequest](docs/UpdatePipelineRequest.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## Author

info@pollex.nl


